==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QGraphicsSceneHelpEvent_shell.cpp <==
#include "QGraphicsSceneHelpEvent_shell.h"
#include <QtJambi/Cast>

#if QT_CONFIG(graphicsview)


void deleter_QGraphicsSceneHelpEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGraphicsSceneHelpEvent")
    QGraphicsSceneHelpEvent *_ptr = reinterpret_cast<QGraphicsSceneHelpEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QGraphicsSceneHelpEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QGraphicsSceneHelpEvent_shell) ); }

jmethodID QGraphicsSceneHelpEvent_shell::__shell_javaMethod(int pos) const { return QGraphicsSceneHelpEvent_shell::__shell()->javaMethod(typeid(QGraphicsSceneHelpEvent), pos); }

// emitting (writeShellConstructor)
QGraphicsSceneHelpEvent_shell::QGraphicsSceneHelpEvent_shell(QEvent::Type type0)
    : QGraphicsSceneHelpEvent(type0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QGraphicsSceneHelpEvent::QGraphicsSceneHelpEvent_shell(QEvent::Type type0)", QGraphicsSceneHelpEvent_shell::__shell())
    QGraphicsSceneHelpEvent_shell::__shell()->constructed(typeid(QGraphicsSceneHelpEvent));
}

// emitting (writeShellDestructor)
QGraphicsSceneHelpEvent_shell::~QGraphicsSceneHelpEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QGraphicsSceneHelpEvent::~QGraphicsSceneHelpEvent()", QGraphicsSceneHelpEvent_shell::__shell())
    QGraphicsSceneHelpEvent_shell::__shell()->destructed(typeid(QGraphicsSceneHelpEvent));
}

void QGraphicsSceneHelpEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QGraphicsSceneHelpEvent_shell*>(ptr)->QGraphicsSceneHelpEvent_shell::__shell()->tryDeleteShell(typeid(QGraphicsSceneHelpEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)

#endif // QT_CONFIG(graphicsview)

// emitting (writeConstructors)
// new QGraphicsSceneHelpEvent(QEvent::Type)
void __qt_construct_QGraphicsSceneHelpEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGraphicsSceneHelpEvent(QEvent::Type)")
#if QT_CONFIG(graphicsview)
    Q_UNUSED(__java_arguments)
    QGraphicsSceneHelpEvent *__qt_this = new(__qtjambi_ptr) QGraphicsSceneHelpEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
}

// new QGraphicsSceneHelpEvent(QEvent::Type)
void __qt_construct_QGraphicsSceneHelpEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGraphicsSceneHelpEvent(QEvent::Type)")
#if QT_CONFIG(graphicsview)
    jobject type0 = __java_arguments[0].l;
    QEvent::Type __qt_type0 = qtjambi_cast<QEvent::Type>(__jni_env, type0);
    QGraphicsSceneHelpEvent *__qt_this = new(__qtjambi_ptr) QGraphicsSceneHelpEvent_shell(QEvent::Type(__qt_type0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
}

// destruct QGraphicsSceneHelpEvent_shell
void __qt_destruct_QGraphicsSceneHelpEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGraphicsSceneHelpEvent")

#if QT_CONFIG(graphicsview)

    reinterpret_cast<QGraphicsSceneHelpEvent_shell*>(ptr)->~QGraphicsSceneHelpEvent_shell();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(graphicsview)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGraphicsSceneHelpEvent::QGraphicsSceneHelpEvent(QEvent::Type)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneHelpEvent_initialize_1native__Lio_qt_widgets_QGraphicsSceneHelpEvent_2Lio_qt_core_QEvent_00024Type_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGraphicsSceneHelpEvent::QGraphicsSceneHelpEvent(QEvent::Type)")
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        jvalue arguments;
        arguments.l = type0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGraphicsSceneHelpEvent_1, sizeof(QGraphicsSceneHelpEvent_shell), typeid(QGraphicsSceneHelpEvent), true, &deleter_QGraphicsSceneHelpEvent, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(type0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneHelpEvent::scenePos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneHelpEvent_scenePos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneHelpEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneHelpEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneHelpEvent::scenePos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->scenePos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneHelpEvent::screenPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneHelpEvent_screenPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneHelpEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneHelpEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneHelpEvent::screenPos()const", __qt_this)
        QPoint __qt_return_value = __qt_this->screenPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneHelpEvent::setScenePos(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneHelpEvent_setScenePos_1native_1cref_1QPointF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneHelpEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneHelpEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneHelpEvent::setScenePos(QPointF)", __qt_this)
        const QPointF& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPointF>(pos0);
        __qt_this->setScenePos(__qt_pos0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(pos0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneHelpEvent::setScreenPos(QPoint)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneHelpEvent_setScreenPos_1native_1cref_1QPoint__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneHelpEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneHelpEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneHelpEvent::setScreenPos(QPoint)", __qt_this)
        const QPoint& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(pos0);
        __qt_this->setScreenPos(__qt_pos0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(pos0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QGraphicsSceneHelpEvent(){
    using namespace RegistryAPI;

#if QT_CONFIG(graphicsview)

    const std::type_info& typeId = registerObjectTypeInfo<QGraphicsSceneHelpEvent>("QGraphicsSceneHelpEvent", "io/qt/widgets/QGraphicsSceneHelpEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QGraphicsSceneHelpEvent, {
        ConstructorInfo(&__qt_construct_QGraphicsSceneHelpEvent_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QGraphicsSceneHelpEvent_1, "Lio/qt/core/QEvent$Type;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGraphicsSceneHelpEvent);
    registerSizeOfShell(typeId, sizeof(QGraphicsSceneHelpEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QGraphicsSceneEvent, QGraphicsSceneHelpEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(graphicsview)

}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QGraphicsSceneHelpEvent_shell.cpp <==
#include "QGraphicsSceneHelpEvent_shell.h"
#include <QtJambi/Cast>

#if QT_CONFIG(graphicsview)


void deleter_QGraphicsSceneHelpEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGraphicsSceneHelpEvent")
    QGraphicsSceneHelpEvent *_ptr = reinterpret_cast<QGraphicsSceneHelpEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QGraphicsSceneHelpEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QGraphicsSceneHelpEvent_shell) ); }

jmethodID QGraphicsSceneHelpEvent_oshell::__shell_javaMethod(int pos) const { return QGraphicsSceneHelpEvent_shell::__shell()->javaMethod(typeid(QGraphicsSceneHelpEvent), pos); }

// emitting (writeShellDestructor)
QGraphicsSceneHelpEvent_shell::~QGraphicsSceneHelpEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QGraphicsSceneHelpEvent::~QGraphicsSceneHelpEvent()", this)
    QGraphicsSceneHelpEvent_shell::__shell()->destructed(typeid(QGraphicsSceneHelpEvent));
}

// emitting (writeShellConstructor)
QGraphicsSceneHelpEvent_shell::QGraphicsSceneHelpEvent_shell(QEvent::Type type0)
    : QGraphicsSceneHelpEvent(type0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QGraphicsSceneHelpEvent::QGraphicsSceneHelpEvent_shell(QEvent::Type type0)", this)
    QGraphicsSceneHelpEvent_shell::__shell()->constructed(typeid(QGraphicsSceneHelpEvent));
}

void QGraphicsSceneHelpEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QGraphicsSceneHelpEvent_shell*>(ptr)->QGraphicsSceneHelpEvent_shell::__shell()->tryDeleteShell(typeid(QGraphicsSceneHelpEvent));
}

void QGraphicsSceneHelpEvent_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QGraphicsSceneHelpEvent_oshell*>(ptr)->QGraphicsSceneHelpEvent_oshell::__shell()->tryDeleteShell(typeid(QGraphicsSceneHelpEvent));
}

// emitting Virtual overrides (virtualFunctions)
QEvent* QGraphicsSceneHelpEvent_oshell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QGraphicsSceneHelpEvent::clone()const", this)
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QGraphicsSceneHelpEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QEvent*>(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnershipAndInvalidate(__jni_env, __java_return_value);
                } else {
                    QGraphicsSceneHelpEvent_shell::__shell()->warnForMethod("QGraphicsSceneHelpEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QGraphicsSceneHelpEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QEvent::clone();
        }
    }else{
        return QEvent::clone();
    }
}

void QGraphicsSceneHelpEvent_oshell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QGraphicsSceneHelpEvent::setAccepted(bool)", this)
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QGraphicsSceneHelpEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QGraphicsSceneHelpEvent_shell::__shell()->warnForMethod("QGraphicsSceneHelpEvent::setAccepted(bool)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QGraphicsSceneHelpEvent::setAccepted(bool)");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)

#endif // QT_CONFIG(graphicsview)

// emitting (writeConstructors)
// new QGraphicsSceneHelpEvent(QEvent::Type)
void __qt_construct_QGraphicsSceneHelpEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGraphicsSceneHelpEvent(QEvent::Type)")
#if QT_CONFIG(graphicsview)
    Q_UNUSED(__java_arguments)
    QGraphicsSceneHelpEvent *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QGraphicsSceneHelpEvent_oshell();
    else
        __qt_this = new(__qtjambi_ptr) QGraphicsSceneHelpEvent_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__qtjambi_has_overrides)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
}

// new QGraphicsSceneHelpEvent(QEvent::Type)
void __qt_construct_QGraphicsSceneHelpEvent_QEvent_Type(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGraphicsSceneHelpEvent(QEvent::Type)")
#if QT_CONFIG(graphicsview)
    jobject type0 = __java_arguments[0].l;
    QEvent::Type __qt_type0 = qtjambi_cast<QEvent::Type>(__jni_env, type0);
    QGraphicsSceneHelpEvent *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QGraphicsSceneHelpEvent_oshell(QEvent::Type(__qt_type0));
    else
        __qt_this = new(__qtjambi_ptr) QGraphicsSceneHelpEvent_shell(QEvent::Type(__qt_type0));
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__qtjambi_has_overrides)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
}

// QGraphicsSceneHelpEvent::QGraphicsSceneHelpEvent(QEvent::Type)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneHelpEvent_initialize_1native__Lio_qt_widgets_QGraphicsSceneHelpEvent_2Lio_qt_core_QEvent_00024Type_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGraphicsSceneHelpEvent::QGraphicsSceneHelpEvent(QEvent::Type)")
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        jvalue arguments;
        arguments.l = type0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGraphicsSceneHelpEvent_QEvent_Type, sizeof(QGraphicsSceneHelpEvent_shell), typeid(QGraphicsSceneHelpEvent), 0, true, &deleter_QGraphicsSceneHelpEvent, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(type0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QGraphicsSceneHelpEvent_shell
void __qt_destruct_QGraphicsSceneHelpEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGraphicsSceneHelpEvent")

#if QT_CONFIG(graphicsview)

    reinterpret_cast<QGraphicsSceneHelpEvent_shell*>(ptr)->~QGraphicsSceneHelpEvent_shell();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(graphicsview)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGraphicsSceneHelpEvent::scenePos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneHelpEvent_scenePos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneHelpEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneHelpEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneHelpEvent::scenePos()const", __this_nativeId)
        QPointF __qt_return_value = __qt_this->scenePos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneHelpEvent::screenPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneHelpEvent_screenPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneHelpEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneHelpEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneHelpEvent::screenPos()const", __this_nativeId)
        QPoint __qt_return_value = __qt_this->screenPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneHelpEvent::setScenePos(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneHelpEvent_setScenePos_1native_1cref_1QPointF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneHelpEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneHelpEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneHelpEvent::setScenePos(QPointF)", __this_nativeId)
        const QPointF& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPointF>(pos0);
        __qt_this->setScenePos(__qt_pos0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(pos0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneHelpEvent::setScreenPos(QPoint)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneHelpEvent_setScreenPos_1native_1cref_1QPoint__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneHelpEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneHelpEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneHelpEvent::setScreenPos(QPoint)", __this_nativeId)
        const QPoint& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(pos0);
        __qt_this->setScreenPos(__qt_pos0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(pos0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QGraphicsSceneHelpEvent(){
    using namespace RegistryAPI;

#if QT_CONFIG(graphicsview)

    const std::type_info& typeId = registerObjectTypeInfo<QGraphicsSceneHelpEvent>("QGraphicsSceneHelpEvent", "io/qt/widgets/QGraphicsSceneHelpEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/core/QEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QGraphicsSceneHelpEvent, {
        ConstructorInfo(&__qt_construct_QGraphicsSceneHelpEvent, nullptr)
       ,ConstructorInfo(&__qt_construct_QGraphicsSceneHelpEvent_QEvent_Type, "Lio/qt/core/QEvent$Type;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGraphicsSceneHelpEvent);
    registerSizeOfShell(typeId, sizeof(QGraphicsSceneHelpEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QGraphicsSceneEvent, QGraphicsSceneHelpEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(graphicsview)

}
